==> open-cluster-management-apps-model-6.1.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/placementrule/v1/PlacementFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.placementrule.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PlacementFluent<A extends PlacementFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildClusterSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getClusterSelector();
  public LabelSelector buildClusterSelector();
  public A withClusterSelector(LabelSelector clusterSelector);
  public Boolean hasClusterSelector();
  public PlacementFluent.ClusterSelectorNested<A> withNewClusterSelector();
  public PlacementFluent.ClusterSelectorNested<A> withNewClusterSelectorLike(LabelSelector item);
  public PlacementFluent.ClusterSelectorNested<A> editClusterSelector();
  public PlacementFluent.ClusterSelectorNested<A> editOrNewClusterSelector();
  public PlacementFluent.ClusterSelectorNested<A> editOrNewClusterSelectorLike(LabelSelector item);
  public A addToClusters(Integer index,GenericClusterReference item);
  public A setToClusters(Integer index,GenericClusterReference item);
  public A addToClusters(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.placementrule.v1.GenericClusterReference... items);
  public A addAllToClusters(Collection<GenericClusterReference> items);
  public A removeFromClusters(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.placementrule.v1.GenericClusterReference... items);
  public A removeAllFromClusters(Collection<GenericClusterReference> items);
  public A removeMatchingFromClusters(Predicate<GenericClusterReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildClusters instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<GenericClusterReference> getClusters();
  public List<GenericClusterReference> buildClusters();
  public GenericClusterReference buildCluster(Integer index);
  public GenericClusterReference buildFirstCluster();
  public GenericClusterReference buildLastCluster();
  public GenericClusterReference buildMatchingCluster(Predicate<GenericClusterReferenceBuilder> predicate);
  public Boolean hasMatchingCluster(Predicate<GenericClusterReferenceBuilder> predicate);
  public A withClusters(List<GenericClusterReference> clusters);
  public A withClusters(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.placementrule.v1.GenericClusterReference... clusters);
  public Boolean hasClusters();
  public A addNewCluster(String name);
  public PlacementFluent.ClustersNested<A> addNewCluster();
  public PlacementFluent.ClustersNested<A> addNewClusterLike(GenericClusterReference item);
  public PlacementFluent.ClustersNested<A> setNewClusterLike(Integer index,GenericClusterReference item);
  public PlacementFluent.ClustersNested<A> editCluster(Integer index);
  public PlacementFluent.ClustersNested<A> editFirstCluster();
  public PlacementFluent.ClustersNested<A> editLastCluster();
  public PlacementFluent.ClustersNested<A> editMatchingCluster(Predicate<GenericClusterReferenceBuilder> predicate);
  public Boolean getLocal();
  public A withLocal(Boolean local);
  public Boolean hasLocal();
  
  /**
   * This method has been deprecated, please use method buildPlacementRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getPlacementRef();
  public ObjectReference buildPlacementRef();
  public A withPlacementRef(ObjectReference placementRef);
  public Boolean hasPlacementRef();
  public PlacementFluent.PlacementRefNested<A> withNewPlacementRef();
  public PlacementFluent.PlacementRefNested<A> withNewPlacementRefLike(ObjectReference item);
  public PlacementFluent.PlacementRefNested<A> editPlacementRef();
  public PlacementFluent.PlacementRefNested<A> editOrNewPlacementRef();
  public PlacementFluent.PlacementRefNested<A> editOrNewPlacementRefLike(ObjectReference item);
  public A withLocal();
  public interface ClusterSelectorNested<N> extends Nested<N>,LabelSelectorFluent<PlacementFluent.ClusterSelectorNested<N>>{
    public N and();
    public N endClusterSelector();
    
  }
  public interface ClustersNested<N> extends Nested<N>,GenericClusterReferenceFluent<PlacementFluent.ClustersNested<N>>{
    public N and();
    public N endCluster();
    
  }
  public interface PlacementRefNested<N> extends Nested<N>,ObjectReferenceFluent<PlacementFluent.PlacementRefNested<N>>{
    public N and();
    public N endPlacementRef();
    
  }
  
}

==> open-cluster-management-apps-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/placementrule/v1/PlacementFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.placementrule.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PlacementFluent<A extends PlacementFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildClusterSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getClusterSelector();
  public LabelSelector buildClusterSelector();
  public A withClusterSelector(LabelSelector clusterSelector);
  public Boolean hasClusterSelector();
  public PlacementFluent.ClusterSelectorNested<A> withNewClusterSelector();
  public PlacementFluent.ClusterSelectorNested<A> withNewClusterSelectorLike(LabelSelector item);
  public PlacementFluent.ClusterSelectorNested<A> editClusterSelector();
  public PlacementFluent.ClusterSelectorNested<A> editOrNewClusterSelector();
  public PlacementFluent.ClusterSelectorNested<A> editOrNewClusterSelectorLike(LabelSelector item);
  public A addToClusters(int index,GenericClusterReference item);
  public A setToClusters(int index,GenericClusterReference item);
  public A addToClusters(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.placementrule.v1.GenericClusterReference... items);
  public A addAllToClusters(Collection<GenericClusterReference> items);
  public A removeFromClusters(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.placementrule.v1.GenericClusterReference... items);
  public A removeAllFromClusters(Collection<GenericClusterReference> items);
  public A removeMatchingFromClusters(Predicate<GenericClusterReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildClusters instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<GenericClusterReference> getClusters();
  public List<GenericClusterReference> buildClusters();
  public GenericClusterReference buildCluster(int index);
  public GenericClusterReference buildFirstCluster();
  public GenericClusterReference buildLastCluster();
  public GenericClusterReference buildMatchingCluster(Predicate<GenericClusterReferenceBuilder> predicate);
  public Boolean hasMatchingCluster(Predicate<GenericClusterReferenceBuilder> predicate);
  public A withClusters(List<GenericClusterReference> clusters);
  public A withClusters(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.placementrule.v1.GenericClusterReference... clusters);
  public Boolean hasClusters();
  public A addNewCluster(String name);
  public PlacementFluent.ClustersNested<A> addNewCluster();
  public PlacementFluent.ClustersNested<A> addNewClusterLike(GenericClusterReference item);
  public PlacementFluent.ClustersNested<A> setNewClusterLike(int index,GenericClusterReference item);
  public PlacementFluent.ClustersNested<A> editCluster(int index);
  public PlacementFluent.ClustersNested<A> editFirstCluster();
  public PlacementFluent.ClustersNested<A> editLastCluster();
  public PlacementFluent.ClustersNested<A> editMatchingCluster(Predicate<GenericClusterReferenceBuilder> predicate);
  public Boolean getLocal();
  public A withLocal(Boolean local);
  public Boolean hasLocal();
  
  /**
   * This method has been deprecated, please use method buildPlacementRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getPlacementRef();
  public ObjectReference buildPlacementRef();
  public A withPlacementRef(ObjectReference placementRef);
  public Boolean hasPlacementRef();
  public PlacementFluent.PlacementRefNested<A> withNewPlacementRef();
  public PlacementFluent.PlacementRefNested<A> withNewPlacementRefLike(ObjectReference item);
  public PlacementFluent.PlacementRefNested<A> editPlacementRef();
  public PlacementFluent.PlacementRefNested<A> editOrNewPlacementRef();
  public PlacementFluent.PlacementRefNested<A> editOrNewPlacementRefLike(ObjectReference item);
  public A withLocal();
  public interface ClusterSelectorNested<N> extends Nested<N>,LabelSelectorFluent<PlacementFluent.ClusterSelectorNested<N>>{
    public N and();
    public N endClusterSelector();
    
  }
  public interface ClustersNested<N> extends Nested<N>,GenericClusterReferenceFluent<PlacementFluent.ClustersNested<N>>{
    public N and();
    public N endCluster();
    
  }
  public interface PlacementRefNested<N> extends Nested<N>,ObjectReferenceFluent<PlacementFluent.PlacementRefNested<N>>{
    public N and();
    public N endPlacementRef();
    
  }
  
}
